(user-guide)=

# User Guide

## Getting started

```{eval-rst}
.. toctree::
    :maxdepth: 1

    getting_started/getting_started
```

## Landmark-based morphometrics

```{eval-rst}
.. toctree::
    :maxdepth: 1

    landmark/landmark
```

## Harmonic-based morphometrics

```{eval-rst}
.. toctree::
    :maxdepth: 1

    harmonic/harmonic_based_morphometrics
```

## Visualizations

```{eval-rst}
.. toctree::
    :maxdepth: 1

    reconstructed_shapes
```

## Dataset loading utilities

```{eval-rst}
.. toctree::
   :maxdepth: 1

   toy_dataset
```
